<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/buttonoverlay.cpp" line="143"/>
        <source>Clear</source>
        <translation>Text löschen</translation>
    </message>
</context>
<context>
    <name>QtConfigArguments</name>
    <message>
        <location filename="../resources/qtconfigarguments.cpp" line="193"/>
        <source>This application requires Windows 10, version 1809 or newer. The current Windows version is older so the application might not work correctly.</source>
        <translation>Diese Anwendung benötigt mindestens Windows 10, version 1809 oder neuer. Die momentane Windows-Version ist älter. Deshalb wird die Anwendung möglicherweise nicht richtig funktionieren.</translation>
    </message>
</context>
<context>
    <name>QtGui::QtLanguageOptionPage</name>
    <message>
        <location filename="../settingsdialog/qtsettings.cpp" line="566"/>
        <source>recognized by Qt as</source>
        <translation>von Qt erkannt als</translation>
    </message>
</context>
<context>
    <name>QtGui::QtOptionCategory</name>
    <message>
        <location filename="../settingsdialog/qtsettings.cpp" line="420"/>
        <source>Qt</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QtUtilities</name>
    <message>
        <location filename="../resources/resources.cpp" line="403"/>
        <source>unable to access file</source>
        <translation>Zugriff auf die Datei ist nicht möglich</translation>
    </message>
    <message>
        <location filename="../resources/resources.cpp" line="406"/>
        <source>file has invalid format</source>
        <translation>Datei hat ungültiges Format</translation>
    </message>
    <message>
        <location filename="../resources/resources.cpp" line="409"/>
        <source>unknown error</source>
        <translation>unbekannter Fehler</translation>
    </message>
    <message>
        <location filename="../resources/resources.cpp" line="411"/>
        <source>Unable to sync settings from &quot;%1&quot;: %2</source>
        <translation>Settings können nicht unter &quot;%1&quot; synchronisiert werden: %2</translation>
    </message>
</context>
<context>
    <name>QtUtilities::AboutDialog</name>
    <message>
        <location filename="../aboutdialog/aboutdialog.ui" line="24"/>
        <location filename="../aboutdialog/aboutdialog.cpp" line="139"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.ui" line="127"/>
        <source>application name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.ui" line="137"/>
        <source>version</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.ui" line="163"/>
        <source>description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.ui" line="185"/>
        <source>website link</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.ui" line="226"/>
        <source>creators</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.ui" line="253"/>
        <source>Using Qt</source>
        <translation>Verwendet Qt</translation>
    </message>
    <message>
        <source>using Qt</source>
        <translation type="vanished">verwendet Qt</translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.cpp" line="62"/>
        <source>developed by %1</source>
        <translation>entwickelt von %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.cpp" line="75"/>
        <source>Linked against:</source>
        <translation>Gegen folgende Bibliotheken gelinkt:</translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.cpp" line="80"/>
        <source>For updates and bug reports visit the &lt;a href=&quot;%1&quot; style=&quot;text-decoration: underline; color: palette(link);&quot;&gt;project website&lt;/a&gt;.</source>
        <translation>Für Aktualisierung und Melden von Fehlern besuche die &lt;a href=&quot;%1&quot; style=&quot;text-decoration: underline; color: palette(link);&quot;&gt;Webseite des Projekts&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.cpp" line="99"/>
        <source>Using &lt;a href=&quot;qtversion&quot;&gt;Qt %1&lt;/a&gt;</source>
        <translation>Verwendet &lt;a href=&quot;qtversion&quot;&gt;Qt %1&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>QtUtilities::EnterPasswordDialog</name>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="12"/>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="51"/>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="183"/>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="198"/>
        <source>Enter the password</source>
        <translation>Passwort eingeben</translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="64"/>
        <source>user name</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="86"/>
        <source>password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="102"/>
        <source>repeat password</source>
        <translation>Password wiederholen</translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="130"/>
        <source>show password</source>
        <translation>Passwort zeigen</translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="137"/>
        <source>don&apos;t use a password</source>
        <translation>Kein Passwort verwenden</translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="213"/>
        <source>Capslock is active</source>
        <translation>Feststelltaste ist aktiviert</translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="239"/>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="254"/>
        <source>Confirm</source>
        <translation>Bestätigen</translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="183"/>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="198"/>
        <source>Enter the new password</source>
        <translation>Neues Passwort festlegen</translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="289"/>
        <source>You didn&apos;t enter a user name.</source>
        <translation>Es wurde kein Benutzername eingegeben.</translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="291"/>
        <source>You didn&apos;t enter a password.</source>
        <translation>Es wurde kein Passwort eingegeben.</translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="296"/>
        <source>You have to enter the new password twice to ensure you enterd it correct.</source>
        <translation>Um sicher zu stellen, dass das neue Passwort richtig eingegeben wurde, muss es zweimal eingegeben werden.</translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="299"/>
        <source>You mistyped the password.</source>
        <translation>Erstes und zweites Passwort stimmen nicht überein.</translation>
    </message>
</context>
<context>
    <name>QtUtilities::PaletteEditor</name>
    <message>
        <location filename="../paletteeditor/paletteeditor.ui" line="20"/>
        <source>Edit Palette</source>
        <translation>Palette ändern</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.ui" line="53"/>
        <source>Tune Palette</source>
        <translation>Palette</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.ui" line="84"/>
        <source>Show Detai&amp;ls</source>
        <translation>Details einblenden</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.ui" line="91"/>
        <source>&amp;Compute Details</source>
        <translation>Details berechnen</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.ui" line="101"/>
        <source>Quick</source>
        <translation>Einfach</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="46"/>
        <source>Save…</source>
        <translation>Speichern…</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="48"/>
        <source>Load…</source>
        <translation>Laden…</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="155"/>
        <source>Color palette configuration (*.ini)</source>
        <translation>Farbpalettenkonfiguration (*.ini)</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="162"/>
        <source>Unable to load &quot;%1&quot;.</source>
        <translation>Fehler beim Laden von &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="167"/>
        <source>&quot;%1&quot; does not contain a valid palette.</source>
        <translation>&quot;%1&quot; enthält keine gültige Farbpalette.</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="180"/>
        <source>Unable to write &quot;%1&quot;.</source>
        <translation>Fehler beim Schreiben von &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="188"/>
        <source>Load palette</source>
        <translation>Palette laden</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="200"/>
        <source>Error reading palette</source>
        <translation>Fehler beim Einlesen der Palette</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="206"/>
        <source>Save palette</source>
        <translation>Palette speichern</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="214"/>
        <source>Error writing palette</source>
        <translation>Fehler beim Schreiben der Palette</translation>
    </message>
</context>
<context>
    <name>QtUtilities::PaletteModel</name>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="416"/>
        <source>Color Role</source>
        <translation>Farbrolle</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="418"/>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="420"/>
        <source>Inactive</source>
        <translation>Inaktiv</translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="422"/>
        <source>Disabled</source>
        <translation>Deaktiviert</translation>
    </message>
</context>
<context>
    <name>QtUtilities::PathSelection</name>
    <message>
        <location filename="../widgets/pathselection.cpp" line="87"/>
        <location filename="../widgets/pathselection.cpp" line="144"/>
        <source>Select ...</source>
        <translation>Wählen ...</translation>
    </message>
    <message>
        <location filename="../widgets/pathselection.cpp" line="92"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="../widgets/pathselection.cpp" line="95"/>
        <source>Explore</source>
        <translation>Im Dateibrowser öffnen</translation>
    </message>
    <message>
        <location filename="../widgets/pathselection.cpp" line="131"/>
        <location filename="../widgets/pathselection.cpp" line="133"/>
        <source>Select path</source>
        <translation>Pfad auswählen</translation>
    </message>
</context>
<context>
    <name>QtUtilities::QtAppearanceOptionPage</name>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="6"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="21"/>
        <source>Use system default</source>
        <translation>Verwende Systemvorgabe</translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="34"/>
        <source>Font</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="71"/>
        <source>More options ...</source>
        <translation>Weitere Optionen ...</translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="93"/>
        <source>Widget style</source>
        <translation>Widget-Stil</translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="132"/>
        <source>Style sheet</source>
        <translation>Stylesheet</translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="162"/>
        <source>Palette</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="175"/>
        <source>select ...</source>
        <translation>Bearbeiten ...</translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="195"/>
        <source>Icon theme</source>
        <translation>Symbole</translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="249"/>
        <source>These settings take effect after restarting the application.
These settings might be overwritten by your Qt platform integration plugin and hence have no effect.</source>
        <translation>Diese Einstellungen wirken sich erst nach einem Neustart der Anwendung aus.
Außerdem werden sie vielleicht vom QPA-Plugin überschrieben und funktionieren daher nicht.</translation>
    </message>
    <message>
        <source>These settings take effect after restarting the application.
These settings might be overwritten by your Qt platfrom integration plugin and hence have no effect.</source>
        <translation type="vanished">Diese Einstellungen wirken sich erst nach einem Neustart der Anwendung aus.
Außerdem werden sie vielleicht vom QPA-Plugin überschrieben und funktionieren daher nicht.</translation>
    </message>
    <message>
        <source>These settings take effect after restarting the application.
These settings might be overwritten by your Qt 5 platfrom integration plugin and hence have no effect.</source>
        <translation type="vanished">Diese Einstellungen wirken sich erst nach einem Neustart der Anwendung aus.
Außerdem werden sie vielleicht vom QPA plugin überschrieben und funktionieren daher nicht.</translation>
    </message>
</context>
<context>
    <name>QtUtilities::QtEnvOptionPage</name>
    <message>
        <location filename="../settingsdialog/qtenvoptionpage.ui" line="14"/>
        <source>Environment/paths</source>
        <translation>Umgebung/Pfade</translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtenvoptionpage.ui" line="28"/>
        <source>Additional plugin directory</source>
        <translation>Zusätzliches Plugin-Verzeichnis</translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtenvoptionpage.ui" line="38"/>
        <source>Additional icon theme search path</source>
        <translation>Zusätzliches Verzeichnis für Symbole</translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtenvoptionpage.ui" line="48"/>
        <source>Additional translation search path</source>
        <translation>Zusätzliches Verzeichnis für Übersetzungen</translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtenvoptionpage.ui" line="79"/>
        <source>These settings take effect after restarting the application.</source>
        <translation>Diese Einstellungen wirken sich erst nach einem Neustart der Anwendung aus.</translation>
    </message>
</context>
<context>
    <name>QtUtilities::QtLanguageOptionPage</name>
    <message>
        <location filename="../settingsdialog/qtlanguageoptionpage.ui" line="6"/>
        <source>Localization</source>
        <translation>Lokalisierung</translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtlanguageoptionpage.ui" line="43"/>
        <source>Locale</source>
        <translation>Gebietsschema</translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtlanguageoptionpage.ui" line="53"/>
        <source>Use system default</source>
        <translation>Verwende Systemvorgabe</translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtlanguageoptionpage.ui" line="98"/>
        <source>These settings take effect after restarting the application.</source>
        <translation>Diese Einstellungen wirken sich erst nach einem Neustart der Anwendung aus.</translation>
    </message>
</context>
<context>
    <name>QtUtilities::RecentMenuManager</name>
    <message>
        <location filename="../misc/recentmenumanager.cpp" line="35"/>
        <source>&amp;Recent</source>
        <translation>&amp;Zuletzt verwendet</translation>
    </message>
    <message>
        <location filename="../misc/recentmenumanager.cpp" line="38"/>
        <source>&amp;Clear list</source>
        <translation>&amp;Liste löschen</translation>
    </message>
    <message>
        <location filename="../misc/recentmenumanager.cpp" line="144"/>
        <source>Recently opened files - </source>
        <translation>Kürzlich geöffnete Dateien - </translation>
    </message>
    <message>
        <location filename="../misc/recentmenumanager.cpp" line="145"/>
        <source>The selected file can&apos;t be found anymore. Do you want to delete the obsolete entry from the list?</source>
        <translation>Die ausgewählte Datei kann nicht mehr gefunden werden. Soll die Datei aus der Liste gelöscht werden?</translation>
    </message>
    <message>
        <location filename="../misc/recentmenumanager.cpp" line="148"/>
        <source>keep entry</source>
        <translation>Eintrag behalten</translation>
    </message>
    <message>
        <location filename="../misc/recentmenumanager.cpp" line="149"/>
        <source>delete entry</source>
        <translation>Eintrag löschen</translation>
    </message>
</context>
<context>
    <name>QtUtilities::SettingsDialog</name>
    <message>
        <location filename="../settingsdialog/settingsdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../settingsdialog/settingsdialog.ui" line="75"/>
        <location filename="../settingsdialog/settingsdialog.cpp" line="153"/>
        <source>No category selected</source>
        <translation>Keine Kategorie gewählt</translation>
    </message>
    <message>
        <location filename="../settingsdialog/settingsdialog.ui" line="93"/>
        <source>Filter</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog/settingsdialog.ui" line="134"/>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../settingsdialog/settingsdialog.ui" line="148"/>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <location filename="../settingsdialog/settingsdialog.ui" line="159"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog/settingsdialog.cpp" line="320"/>
        <source>&lt;p&gt;&lt;b&gt;Errors occurred when applying changes:&lt;/b&gt;&lt;/p&gt;&lt;ul&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Beim Anwenden der Einstellungen sind Fehler aufgetreten:&lt;/b&gt;&lt;/p&gt;&lt;ul&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog/settingsdialog.cpp" line="325"/>
        <source>unknown error</source>
        <translation>unbekannter Fehler</translation>
    </message>
    <message>
        <source>unknonw error</source>
        <translation type="vanished">unbekannter Fehler</translation>
    </message>
</context>
<context>
    <name>Utilities::windowTitle</name>
    <message>
        <location filename="../misc/dialogutils.cpp" line="36"/>
        <source>Unsaved - %1</source>
        <translation>Nicht gespeichert - %1</translation>
    </message>
    <message>
        <location filename="../misc/dialogutils.cpp" line="39"/>
        <source>%1 - %2 - %3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../misc/dialogutils.cpp" line="44"/>
        <source>*Unsaved - %1</source>
        <translation>*Nicht gespeichert - %1</translation>
    </message>
    <message>
        <location filename="../misc/dialogutils.cpp" line="47"/>
        <source>*%1 - %2 - %3</source>
        <translation></translation>
    </message>
</context>
</TS>
